@@ -5,9 +5,10 @@ proptest! {
     #![proptest_config(ProptestConfig::with_cases(10000))]
     #[test]
     fn bytes_to_config_roundtrip(bytes in any::<u16>()) {
+        let top_most_mask = 0b0011_1111_1111_1111;
         if let Ok(config) = Configuration::try_from(bytes) {
             let original = u16::from(config);
-            assert_eq!(bytes, original);
+            assert_eq!(bytes & top_most_mask, original & top_most_mask);
         }
     }
 
@@ -16,17 +17,4 @@ proptest! {
         let bytes = u16::from(config);
         assert_eq!(config, Configuration::try_from(bytes).unwrap());
     }
-
-    #[test]
-    fn partial_eq(first in any::<u16>(), second in any::<u16>()) {
-        if let Ok(first_config) = Configuration::try_from(first) {
-            if let Ok(second_config) = Configuration::try_from(second) {
-                if first != second {
-                    assert_ne!(first_config, second_config);
-                } else {
-                    assert_eq!(first_config, second_config);
-                }
-            }
-        }
-    }
 }
